all.Enoms<-function(){
     cat("\n")
     note_for_Eno_input()
     cat("\n")
     note_for_close_window()
     EnoMSpar<-data.frame(subject=c(1,2),Gender=c(0),TBW=c(0),Scr=c(0),D=c(0),tau=c(0),Amax=c(0))
     EnoMSpar<-edit(EnoMSpar)
##     EnoMSpar<-ymscheck(EnoMSpar)
     cat("\n")
     Eno.ms(length(EnoMSpar$subject),EnoMSpar$Amax,EnoMSpar$tau,EnoMSpar$D,EnoMSpar$TBW,EnoMSpar$Gender,EnoMSpar$Scr)
     note_for_convergence_plots()
     note_for_plot()
     convergence_plots_con()
     note_for_Eno_output()   
     show(samplesStats("*"))
     cat("\n") 
     C<-Enocpr(EnoMSpar$D,EnoMSpar$tau)
     sim<-matrix(C[ ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Amaxss_pr (IU/mL)")
     show(coutput)   
     cat("\n") 
     cal.again()
}